summaryrefslogtreecommitdiffstats
path: root/slv2/pluginui.h
diff options
context:
space:
mode:
authorDavid Robillard <d@drobilla.net>2008-01-25 06:55:57 +0000
committerDavid Robillard <d@drobilla.net>2008-01-25 06:55:57 +0000
commit6f4460aee9962a49ae872eef42ba75a439ea6e59 (patch)
treedd08af14a835d0d6f77aa6a3c4c9047ceb4b307f /slv2/pluginui.h
parent361f21b9e1f59bd602d0e1ed8b80f726605995be (diff)
downloadlilv-6f4460aee9962a49ae872eef42ba75a439ea6e59.tar.gz
lilv-6f4460aee9962a49ae872eef42ba75a439ea6e59.tar.bz2
lilv-6f4460aee9962a49ae872eef42ba75a439ea6e59.zip
Overhaul SLV2 API to return/take SLV2Value (instead of strings or primitives) wherever possible.
Make 'index' a fundemental property of ingen ports. git-svn-id: http://svn.drobilla.net/lad/slv2@1113 a436a847-0d15-0410-975c-d299462d15a1
Diffstat (limited to 'slv2/pluginui.h')
-rw-r--r--slv2/pluginui.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/slv2/pluginui.h b/slv2/pluginui.h
index b01bf34..8fc1f06 100644
--- a/slv2/pluginui.h
+++ b/slv2/pluginui.h
@@ -34,7 +34,7 @@ extern "C" {
*
* Time = O(1)
*/
-const char*
+SLV2Value
slv2_ui_get_uri(SLV2UI ui);
@@ -50,14 +50,14 @@ slv2_ui_get_classes(SLV2UI ui);
/** Check whether a plugin UI is a given type.
*
* \param ui The Plugin UI
* \param type_uri The URI of the LV2 UI type to check this UI against
*
* Time = O(1)
*/
bool
-slv2_ui_is_a(SLV2UI ui, const char* type_uri);
-
+slv2_ui_is_a(SLV2UI ui, SLV2Value class_uri);
+
/** Get the URI for a Plugin UI's bundle.
*
@@ -65,7 +65,7 @@ slv2_ui_is_a(SLV2UI ui, const char* type_uri);
*
* Time = O(1)
*/
-const char*
+SLV2Value
slv2_ui_get_bundle_uri(SLV2UI ui);
@@ -75,7 +75,7 @@ slv2_ui_get_bundle_uri(SLV2UI ui);
*
* Time = O(1)
*/
-const char*
+SLV2Value
slv2_ui_get_binary_uri(SLV2UI ui);
@@ -50,14 +50,14 @@ slv2_ui_get_classes(SLV2UI ui);
/** Check whether a plugin UI is a given type.
*
- * \param ui The Plugin UI
- * \param type_uri The URI of the LV2 UI type to check this UI against
+ * \param ui The Plugin UI
+ * \param class_uri The URI of the LV2 UI type to check this UI against
*
* Time = O(1)